/**
  * ******************************************************
  *                                                       *
  *   Copyright (C) Microsoft. All rights reserved.       *
  *                                                       *
  *******************************************************
  */
"use strict";
const fs = require("fs");
const path = require("path");
const vcremoteUtility = require("./resources-manager");
var resources = vcremoteUtility.ResourcesManager;
var VCRemoteUtility;
(function (VCRemoteUtility) {
    class ProcessLogger {
        constructor() {
            this._stream = null;
        }
        begin(logDir, logFileName, language, proc) {
            var pathToLog = path.join(logDir, logFileName);
            this._stream = fs.createWriteStream(pathToLog);
            this._stream.on("error", function (err) {
                console.error(resources.getStringForLanguage(language, "ProcessLogError"), pathToLog, err);
            });
            var me = this;
            proc.stdout.on("data", function (data) {
                me.log(data);
            });
            proc.stderr.on("data", function (data) {
                me.log(data);
            });
            proc.on("exit", function (code) {
                if (code) {
                    me.log(resources.getStringForLanguage(language, "LoggedProcessTerminatedWithCode", code));
                }
                me.end();
            });
        }
        end() {
            if (this._stream) {
                this._stream.end();
            }
            this._stream = null;
        }
        log(message) {
            if (this._stream) {
                this._stream.write(message);
            }
        }
    }
    VCRemoteUtility.ProcessLogger = ProcessLogger;
})(VCRemoteUtility || (VCRemoteUtility = {}));
module.exports = VCRemoteUtility;
